install_report_handler

Function install_report_handler 

pub fn install_report_handler()
Install the default miette graphical report handler.

Idempotent. Safe to call from main() before tokio::main expansion or from inside an Application::run() invocation.

If another caller (including a previous call to this function, to install_with_footer, or to miette::set_hook directly) has already installed a hook, this call is a no-op — the existing hook is preserved.